crystal_toolkit.renderables.phasediagram module — Crystal Toolkit documentation

# crystal_toolkit.renderables.phasediagram module

crystal_toolkit.renderables.phasediagram.get_plot(self, show_unstable=0.2, label_stable=True, label_unstable=True, ordering=None, energy_colormap=None, process_attributes=False, label_uncertainties=False)

  Plot a PhaseDiagram.

  Parameters

    - show_unstable – Whether unstable (above the hull) phases will be plotted. If a number > 0 is entered, all phases with e_hull < show_unstable (eV/atom) will be shown.

    - label_stable – Whether to label stable compounds.

    - label_unstable – Whether to label unstable compounds.

    - ordering – Ordering of vertices (matplotlib backend only).

    - energy_colormap – Colormap for coloring energy (matplotlib backend only).

    - process_attributes – Whether to process the attributes (matplotlib backend only).

    - plt – Existing plt object if plotting multiple phase diagrams ( matplotlib backend only).

    - label_uncertainties – Whether to add error bars to the hull (plotly backend only). For binaries, this also shades the hull with the uncertainty window